#!/bin/sh
#
#    Backups (tar and gzip) and optionally removes a directory.
#
# Usage:
#      backupdir.sh [-r] -d <destination> -s <source directory>
#
#    -d <destination>      : name of the backup file (without the tar.gz suffix)
#    -s <source directory> : directory to be backed up
#    -r                    : remove the directory after a successfull backup
#
#  Last Modified by : $Author$
#  Last Modified at : $Date$
#  RCS File Name    : $RCSfile$
#  RCS Revision     : $Revision$
#  Locked by        : $Locker$
#  Symbolic name    : $Name$
#  State            : $State$
#

. $HOME/etc/setenv.sh

LOGGER="/usr/bin/logger"
TAG="backupdir[$$]"

$LOGGER -p $LOG_FACILITY.info -t "$TAG" "$@"

SOURCE=""
DEST=""
REMOVE="false"

while getopts 'd:s:r' OPT; do
	case $OPT in
		s) SOURCE="$OPTARG" ;;
		d) DEST="$OPTARG" ;;
		r) REMOVE="true" ;;
		*) ERRMSG="Invalid_Parameter:$OPT" ;;
	esac
done

if [ -z "$SOURCE" -o -z "$DEST" ] ; then
	echo "Missing argument" >&2
	exit 1
fi

CWD=`pwd`

WDIR=`dirname $SOURCE`
WNAME=`basename $SOURCE`

$LOGGER -p $LOG_FACILITY.info -t "$TAG" "$WDIR $WNAME"

cd "$WDIR"
if [ $? -ne 0 ] ; then
	echo "Could not change current directory to $WDIR" >&2
	exit 1
fi

if [ ! -e "$WNAME" ] ; then
	echo "$WNAME does not exist" >&2
	cd $CWD
	exit 1
fi

tar cf "${DEST}.tar" "${WNAME}"
if [ $? -ne 0 ] ; then
	echo "Error tar-ing ${WNAME}"
	cd $CWD
	exit 1
fi

gzip "${DEST}.tar"
if [ $? -ne 0 ] ; then
	echo "Error gzip-ing ${DEST}.tar"
	cd $CWD
	exit 1
fi


if [ "$REMOVE" = "true" ] ; then
	if [ "$WDIR" = "$DICOM_DATA" -o "${WDIR#$REPOSITORY_DICOM_DATA}" != "$WDIR" ] ; then
		$REPOSITORYHANDLER_HOME/bin/removeResource $REPOSITORY_DATA_DICOM $WNAME
	elif [ "$WDIR" = "$CACHE" -o "${WDIR#$REPOSITORY_CACHE}" != "$WDIR" ] ; then
		$REPOSITORYHANDLER_HOME/bin/removeResource $REPOSITORY_CACHE $WNAME
	elif [ "$WDIR" = "$PROCESSED" -o "${WDIR#$REPOSITORY_PROCESSED}" != "$WDIR" ] ; then
		$REPOSITORYHANDLER_HOME/bin/removeResource $REPOSITORY_PROCESSED $WNAME
	else
		[ -e "$WNAME" ] && rm -fr "$WNAME"
	fi
	cd $CWD
fi

$LOGGER -p $LOG_FACILITY.info -t "$TAG" "${SOURCE} has been backed up into ${DEST}.tar.gz (remove: $REMOVE)"

cd $CWD
exit 0
